@@ -1,6 +1,6 @@
 import asyncio
 from unittest import mock
-from aiohttp.multidict import CIMultiDict
+from multidict import CIMultiDict
 from aiohttp.signals import Signal
 from aiohttp.web import Application
 from aiohttp.web import Request, Response
